==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Input/cue/translations/cue_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>Plugin CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>Arquivos CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="98"/>
        <source>About CUE Audio Plugin</source>
        <translation>Sobre o pugin CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="99"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Plugin Qmmp CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="100"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Preferências do plugin CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Definições gerais</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Se possível, carregar arquivos CUE incorretos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Codificação CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Detecção automática de caracteres</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Codificação pré-definida:</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/cue/translations/cue_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="39"/>
        <source>CUE Plugin</source>
        <translation>Plugin CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="42"/>
        <source>CUE Files</source>
        <translation>Arquivos CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="91"/>
        <source>About CUE Audio Plugin</source>
        <translation>Sobre o pugin CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="92"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Plugin Qmmp CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="93"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Preferências do plugin CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Definições gerais</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Se possível, carregar arquivos CUE incorretos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Codificação CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Detecção automática de caracteres</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Codificação pré-definida:</translation>
    </message>
</context>
</TS>
